@@ -118,6 +118,7 @@ gboolean send_jpeg(unsigned char *data)
     soup_session=soup_session_sync_new_with_options(SOUP_SESSION_PROXY_URI,soup_proxy_uri,NULL);
   } else {
     g_print("Automatic proxy mode not supported\n");
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -148,6 +149,7 @@ gboolean send_jpeg(unsigned char *data)
       g_error_free(error);
       gdk_pixbuf_unref(pixbuf);
       g_free(buffer_size);
+      g_object_unref(soup_session);
       return FALSE;
     }
   
@@ -164,6 +166,7 @@ gboolean send_jpeg(unsigned char *data)
     g_object_unref (rpc_response);
     g_free(b_encoded);
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -195,6 +198,7 @@ gboolean send_jpeg(unsigned char *data)
     g_object_unref (rpc_response);
     g_free(b_encoded);
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
   g_print("b\n");
@@ -207,6 +211,7 @@ gboolean send_jpeg(unsigned char *data)
     g_object_unref (rpc_response);
     g_free(b_encoded);
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -220,6 +225,7 @@ gboolean send_jpeg(unsigned char *data)
     g_object_unref (rpc_response);
     g_free(b_encoded);
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -237,18 +243,20 @@ gboolean send_jpeg(unsigned char *data)
   } else {
     g_print("Sending pic: FAILED\n");
   }
-  g_free(bo);
 
   g_print("e\n");
 
   /* Free allocated resources and return TRUE which means
    * that the operation was succesful */
+
   gdk_pixbuf_unref(pixbuf);
   g_free(buffer);
   g_free(buffer_size);
   g_object_unref (rpc_response);
   g_free(b_encoded);
   g_object_unref(msg);
+  g_free(bo);
+  g_object_unref(soup_session);
   return TRUE;
 }
 
@@ -432,6 +440,28 @@ void load_positions_from_file(){
 }
 
 
+int free_stuff_and_die(){
+  g_print("free_stuff_and_die\n");
+  save_positions_to_file();
+  g_free(xmlrpc_id);
+  g_free(xmlrpc_password);
+  g_free(xmlrpc_server);
+
+  if(http_proxy_host!=NULL){
+    g_free(http_proxy_host);
+  }
+
+  if(https_proxy_host!=NULL){
+    g_free(https_proxy_host);
+  }
+
+  if(soup_proxy_uri_string!=NULL){
+    g_free(soup_proxy_uri_string);
+    soup_uri_free (soup_proxy_uri);
+  }
+  syslog(LOG_INFO, "%s daemon exiting", DAEMON_NAME);
+  exit(EXIT_SUCCESS);
+}
  
 void signal_handler(int sig) {
  
@@ -441,12 +471,10 @@ void signal_handler(int sig) {
     break;
   case SIGTERM:
     syslog(LOG_WARNING, "Received SIGTERM signal.");
-    save_positions_to_file();
-    exit(EXIT_SUCCESS);
+    free_stuff_and_die();
     
   case SIGINT:
-    save_positions_to_file();
-    exit(EXIT_SUCCESS);
+    free_stuff_and_die();
   default:
     syslog(LOG_WARNING, "Unhandled signal: %d", sig);
     break;
@@ -651,6 +679,7 @@ void send_gps_infos(){
   //soup_session=soup_session_sync_new_with_options(SOUP_SESSION_MAX_CONNS,5);
   //soup_session=soup_session_sync_new();
   if(proxy_mode==CON_IC_PROXY_MODE_NONE) {
+    g_print("no proxy\n");
     soup_session=soup_session_sync_new();
   } else if (proxy_mode==CON_IC_PROXY_MODE_MANUAL){
     g_print("using a manual proxy:%s\n",soup_proxy_uri_string);
@@ -675,6 +704,7 @@ void send_gps_infos(){
       msg = soup_xmlrpc_message_new (uri);
       if (!msg) {
 	g_print("Could not create web service request to '%s'\n", uri);
+	g_object_unref(soup_session);
 	break;
       }
       soup_xmlrpc_message_start_call(msg,"store_location");
@@ -706,6 +736,8 @@ void send_gps_infos(){
       g_print("rpc_status=%i\n",rpc_status);
       if(rpc_status!=200){
 	g_print("Problem with XMLRPC communication\n");
+	g_object_unref(msg);
+	g_object_unref(soup_session);
 	break;
       }
 
@@ -713,6 +745,8 @@ void send_gps_infos(){
       rpc_response=soup_xmlrpc_message_parse_response (SOUP_XMLRPC_MESSAGE (msg));
       if (!rpc_response) {
 	g_print("Could not parse XMLRPC response\n");
+	g_object_unref(msg);
+	g_object_unref(soup_session);
 	break;
       }
 
@@ -720,6 +754,9 @@ void send_gps_infos(){
       value = soup_xmlrpc_response_get_value (rpc_response);
       if (!value) {
 	g_print("No response value in XMLRPC response\n");
+	g_object_unref(msg);
+	g_object_unref(rpc_response);
+	g_object_unref(soup_session);
 	break;
       }
 
@@ -743,10 +780,10 @@ void send_gps_infos(){
       //g_slist_foreach(gps_positions, show_locations, NULL);
       //g_print("___\n");
       new_head=next_head;
-
       g_object_unref(msg);
-    }
 
+    }
+  g_object_unref(soup_session);
 }
 
 
@@ -791,6 +828,7 @@ gboolean test_xmlrpc_login(){
   g_print("rpc_status=%i\n",rpc_status);
   if(rpc_status!=200){
     g_print("Problem with XMLRPC communication\n");
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -798,6 +836,7 @@ gboolean test_xmlrpc_login(){
   if (!rpc_response) {
     g_print("Could not parse XMLRPC response\n");
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
 
@@ -805,6 +844,7 @@ gboolean test_xmlrpc_login(){
   if (!value) {
     g_print("No response value in XMLRPC response\n");
     g_object_unref(msg);
+    g_object_unref(soup_session);
     return FALSE;
   }
   
@@ -815,10 +855,12 @@ gboolean test_xmlrpc_login(){
 
   if(*b==TRUE){
     g_print("OK\n");
+    g_object_unref(soup_session);
     g_free(b);
     return TRUE;
   } else {
     g_print("NOPE\n");
+    g_object_unref(soup_session);
     g_free(b);
     return FALSE;
   }
@@ -954,10 +996,17 @@ gboolean my_timeout(gpointer loop) {
   //static double cnt=1;
   g_print("my timeout\n");
   g_print("id=%s password=%s server=%s\n",xmlrpc_id,xmlrpc_password,xmlrpc_server);
+  
   //GMainLoop *mloop=(GMainLoop *) loop;
 
-  //g_main_loop_quit (mloop);
 
+  if(test_xmlrpc_login()==TRUE) {
+    g_print("login ok\n");
+  }else{
+    g_print("login not ok\n");
+  }
+  g_print("goodbye\n");
+  g_main_loop_quit (loop);
   //return FALSE;
   return TRUE;
 }
@@ -1125,17 +1174,14 @@ int main(int argc, char *argv[]) {
   //connection_available();
   //connection_available();
   //send_jpeg(NULL);
-  
+  //send_gps_infos();  
   g_main_loop_run(mainloop);
   osso_deinitialize(osso_context);
 
   gst_object_unref(GST_OBJECT(pipeline));
   free(system_dbus);
-  g_free(xmlrpc_id);
-  g_free(xmlrpc_password);
-  g_free(xmlrpc_server);
-  syslog(LOG_INFO, "%s daemon exiting", DAEMON_NAME);
-  exit(EXIT_SUCCESS);
+  exit(free_stuff_and_die());
+
 }
 
 
